Package: medAdherence
Type: Package
Title: Medication Adherence: Commonly Used Definitions
Version: 1.03
Date: 2012-04-12
Author: Xiangyang Ye, Pharmacotherapy Outcomes Research Center,
        University of Utah
Maintainer: Xiangyang Ye <xyexye08@gmail.com>
Description: Medication Adherence: Commonly Used Definitions
License: GPL-2
LazyLoad: yes
Packaged: 2012-04-13 20:38:25 UTC; u0585652
Repository: CRAN
Date/Publication: 2012-04-14 05:47:04
